@@ -49,7 +49,7 @@ void libglade_log_handler (const gchar    *log_domain,
 
 guint set_log_handler(JNIEnv* env) 
 {
-      GLogLevelFlags fatal_mask;
+      // GLogLevelFlags fatal_mask;
 
       //      fatal_mask = g_log_set_always_fatal (G_LOG_FATAL_MASK);
       //      fatal_mask |= G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
@@ -71,11 +71,11 @@ static void xml_connect(const gchar *handler_name, GObject *_source,
 {
     JNIEnv *env = ((struct jglade_info *)i)->env;
     jobject obj = ((struct jglade_info *)i)->o;
-    jclass cls;
-    jmethodID getWidgetMID;
+    // jclass cls;
+    // jmethodID getWidgetMID;
 
     jstring handler, signal, data;
-    jobject source, target;
+    // jobject source, target;
 
     if ((*env)->ExceptionCheck(env)) {
 	// debug
@@ -129,10 +129,10 @@ Java_org_gnu_glade_LibGlade_glade_1xml_1new_1from_1buffer(
   JNIEnv *env, jobject o, jbyteArray buffer, jstring root) 
 {
     GladeXML *xml;
-    struct jglade_info i;
+    // struct jglade_info i;
     char *rootname;
     guint handler_id;
-    jthrowable exc;
+    // jthrowable exc;
     jbyte *buf;
     int len;
 
